#
# spec file for package borgmatic
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           borgmatic
Version:        1.8.0
Release:        bp156.1.35
Summary:        Automation tool for borgbackup
License:        GPL-3.0-only
Group:          Productivity/Archiving/Backup
URL:            https://torsion.org/borgmatic/
Source:         https://github.com/witten/borgmatic/archive/%{version}.tar.gz#/borgmatic-%{version}.tar.gz
# PATCH-FIX-OPENSUSE
Patch1:         skip-tests.patch
# PATCH-FIX-OPENSUSE
Patch2:         support-python3.6.patch
# testing requirements
BuildRequires:  borgbackup
# To create the manpage
BuildRequires:  pandoc
BuildRequires:  pkgconfig
BuildRequires:  python3 >= 3.6
BuildRequires:  python3-PyYAML
BuildRequires:  python3-appdirs
BuildRequires:  python3-atomicwrites
BuildRequires:  python3-attrs
BuildRequires:  python3-click
BuildRequires:  python3-colorama
BuildRequires:  python3-coverage
BuildRequires:  python3-docopt
BuildRequires:  python3-flake8
BuildRequires:  python3-flexmock
BuildRequires:  python3-jsonschema >= 3.2.0
BuildRequires:  python3-mccabe
BuildRequires:  python3-more-itertools
BuildRequires:  python3-pluggy
BuildRequires:  python3-py
BuildRequires:  python3-pycodestyle
BuildRequires:  python3-pyflakes
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-cov
BuildRequires:  python3-python-dateutil
BuildRequires:  python3-requests
BuildRequires:  python3-ruamel.yaml
BuildRequires:  python3-setuptools
BuildRequires:  python3-toml
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libsystemd)
Requires:       borgbackup
Requires:       python3-colorama
Requires:       python3-jsonschema >= 3.2.0
Requires:       python3-requests
Requires:       python3-ruamel.yaml < 0.18.0
Requires:       python3-ruamel.yaml > 0.15.0
Requires:       python3-setuptools
ExcludeArch:    %ix86
BuildArch:      noarch

%description
borgmatic is a Python wrapper script for the Borg backup software
that initiates a backup, prunes any old backups according to a
retention policy, and validates backups for consistency. The script
supports specifying your settings in a declarative configuration file
rather than having to put them all on the command-line, and handles
common errors.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

sed -i -e "s/colorama>=0.4.1,<0.5/colorama>=0.3.9/" setup.py
%if 0%{?suse_version} <= 1500
sed -i -e "s/^LogRateLimitIntervalSec=/#LogRateLimitIntervalSec=/" sample/systemd/borgmatic.service
%endif

# Make sample files use the borgmatic command on /usr/bin, not /usr/local/bin
perl -pi -e "s,PATH=\\$PATH:/usr/local/bin /root/.local/bin/borgmatic,/usr/bin/borgmatic," sample/cron/borgmatic
perl -pi -e "s,/root/.local/bin/borgmatic,/usr/bin/borgmatic," sample/systemd/borgmatic.service
perl -pi -e "s,/root/.local/bin/borgmatic,/usr/bin/borgmatic," sample/systemd/borgmatic-user.service
perl -pi -e "s,=sleep,=/usr/bin/sleep," sample/systemd/borgmatic.service
perl -pi -e "s,=sleep,=/usr/bin/sleep," sample/systemd/borgmatic-user.service
perl -pi -e "s,=systemd-inhibit,=/usr/bin/systemd-inhibit," sample/systemd/borgmatic.service
perl -pi -e "s/ruamel.yaml>0.15.0,<0.17.0/ruamel.yaml/" setup.py
perl -pi -e "s/packages=find_packages\(\)/packages=find_packages(exclude=('tests*',))/" setup.py

%build
# Create the manpage
pandoc -s -f markdown -t man README.md -o borgmatic.1

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
install -d %{buildroot}%{_sysconfdir}/borgmatic
install -d %{buildroot}%{_sysconfdir}/borgmatic.d
install -d %{buildroot}%{_docdir}/%{name}/sample/cron
install -m 0644 sample/cron/borgmatic %{buildroot}%{_docdir}/%{name}/sample/cron/
install -d %{buildroot}%{_docdir}/%{name}/sample/systemd
install -m 0644 sample/systemd/borgmatic* %{buildroot}%{_docdir}/%{name}/sample/systemd/
install -d %{buildroot}%{_unitdir}/
install -m 0644 sample/systemd/borgmatic.* %{buildroot}%{_unitdir}/

install -D -m 0644 borgmatic.1 %{buildroot}%{_mandir}/man1/borgmatic.1
mkdir -p %{buildroot}%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}%{_sbindir}/rcborgmatic

%check
# testing the build is a little awkward, since the original testsuite is based on tox and
# tox tries to create a virtual environment, that we need tight control on in order to get
# it to behave in our build system (offline mode, use site packages). OTOH, without the
# venv, we face problems with setuptools (borg uses pkg_resources to locate the installed
# package), while py.test relies on the usual module handling. <hpj@urpla.net>
export LANG=en_US.UTF-8
python3 -m venv --system-site-packages --without-pip borgmatic-env
source borgmatic-env/bin/activate
python3 setup.py install
PYTHONPATH=$(pwd) py.test -v --pyargs borgmatic tests

%post
%service_add_post borgmatic.service
if [ "$1" = 1 -a ! -f "%{_sysconfdir}/borgmatic/config.yaml" ]; then
    %{_bindir}/borgmatic config generate
fi

%pre
%service_add_pre borgmatic.service

%preun
%service_del_preun borgmatic.service

%postun
%service_del_postun borgmatic.service

%files
%doc AUTHORS NEWS README.md
%license LICENSE
%config %ghost %{_sysconfdir}/borgmatic/config.yaml
%dir %{_sysconfdir}/borgmatic
%dir %{_sysconfdir}/borgmatic.d
%dir %{_docdir}/%{name}/sample
%dir %{_docdir}/%{name}/sample/cron
%dir %{_docdir}/%{name}/sample/systemd
%{python3_sitelib}/borgmatic/
%{python3_sitelib}/borgmatic-%{version}-py%{py3_ver}.egg-info
%{_unitdir}/borgmatic.service
%{_unitdir}/borgmatic.timer
%{_bindir}/borgmatic
%{_sbindir}/rcborgmatic
%{_bindir}/generate-borgmatic-config
%{_bindir}/validate-borgmatic-config
%{_mandir}/man1/borgmatic.1%{?ext_man}
%{_docdir}/%{name}/sample/cron/
%{_docdir}/%{name}/sample/systemd/

%changelog
* Fri Jul 21 2023 Paolo Stivanin <info@paolostivanin.com>
- update to 1.8.0:
  * BREAKING: For the "borgmatic borg" action, instead of
    implicitly injecting repository/archive into the resulting Borg
    command-line, pass repository to Borg via an environment
    variable and make archive available for explicit use in your
    commands.
  * Fix an error when running "borg key export" through borgmatic.
  * Fix an error when dumping a database and the "exclude_nodump"
    option is set.
  * Add "check_i_know_what_i_am_doing" option to bypass Borg
    confirmation prompt when running "check --repair".
  * When merging two configuration files, error gracefully if the
    two files do not adhere to the same format.
  * Remove configuration sections ("location:", "storage:",
    "hooks:" etc.), while still keeping deprecated support for
    them. Now, all options are at the same level, and you don't
    need to worry about commenting/uncommenting section headers
    when you change an option (if you remove your sections first).
  * BREAKING: The retention prefix and the consistency prefix
    can no longer have different values (unless one is not set).
  * BREAKING: The storage umask and the hooks umask can no longer
    have different values (unless one is not set).
  * BREAKING: Flags like "--config" that previously took multiple
    values now need to be given once per value, e.g.
    "--config first.yaml --config second.yaml" instead of
    "--config first.yaml second.yaml". This prevents argument
    parsing errors on ambiguous commands.
  * BREAKING: Remove the deprecated (and silently ignored)
    "--successful" flag on the "list" action, as newer versions
    of Borg list successful (non-checkpoint) archives by default.
  * All deprecated configuration option values now generate
    warning logs.
  * Remove the deprecated (and non-functional) "--excludes"
    flag in favor of excludes within configuration.
  * Fix an error when logging too-long command output during
    error handling. Now, long command output is truncated
    before logging.
* Thu Jun 29 2023 Jan Baier <jbaier@suse.com>
- update to 1.7.15
  * Add configuration options and command-line flags for backing up a database
    from one location while restoring it somewhere else.
  * Add a documentation troubleshooting note for MySQL/MariaDB authentication
    errors.
  * Remove upgrade-borgmatic-config command for upgrading borgmatic 1.1.0
    INI-style configuration.
  * Deprecate generate-borgmatic-config in favor of new "config generate"
    action.
  * Deprecate validate-borgmatic-config in favor of new "config validate"
    action.
  * Extract borgmatic configuration from backup via new "config bootstrap"
    action—even when borgmatic has no configuration yet!
  * Add sample systemd user service for running borgmatic as a non-root user.
  * Fix an error when "data" check time files are accessed without getting
    upgraded first.
- update to 1.7.14:
  * Add a new verbosity level (-2) to disable output entirely (for console,
    syslog, log file, or monitoring), so not even errors are shown.
  * Tweak archive check probing logic to use the newest timestamp found when
    multiple exist.
  * Add Borg 2 date-based matching flags to various actions for archive
    selection.
  * Fix an error when loading the configuration schema on Fedora Linux.
  * Fix "check" action error when repository and archive checks are configured
    but the archive gets skipped due to the configured frequency.
  * Fix "--archive latest" on "list" and "info" actions that only worked on the
    first of multiple configured repositories.
* Fri Jun  2 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.13:
  * Restore particular PostgreSQL schemas from a database
    dump via "borgmatic restore --schema"
    flag.
  * Fix error from PostgreSQL when dumping a database with
    a "format" of "plain".
  * : Fix PostgreSQL hook to support "psql_command" and
    "pg_restore_command" options containing
    commands with arguments.
  * Fix calls to psql in PostgreSQL hook to ignore
    "~/.psqlrc", whose settings can break
    database dumping.
  * Add support for logging each log line as a JSON object
    via global "--log-json" flag.
  * Fix "source_directories_must_exist" option to expand
    globs and tildes in source directories.
  * Add fish shell completion script so you can tab-
    complete on the borgmatic command-line.
  * Fix borgmatic error when not finding the configuration
    schema for certain "pip install --editable" development
    installs.
  * Fix archive checks being skipped even when particular
    archives haven't been checked
    recently. This occurred when using multiple borgmatic
    configuration files with different
    "archive_name_format"s, for instance.
  * Fix error in "borgmatic restore" action when the
    configured repository path is relative
    instead of absolute.
  * Run "borgmatic borg" action without capturing output so
    interactive prompts and flags like
    "--progress" still work.
* Fri Jun  2 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.12:
  * Add "log_file" context to command hooks so your scripts
    can consume the borgmatic log file.
  * Fix error when running the "info" action with the
    "--match-archives" or "--archive"
    flags. Also fix the "--match-archives"/"--archive" flags
  * Fix error when running the "prune" action with both
    "archive_name_format" and "prefix" options set.
  * Selectively shallow merge certain mappings or sequences
    when including configuration files.
  * Selectively omit list values when including
    configuration files.
  * View the results of configuration file merging via
    "validate-borgmatic-config --show" flag.
  * BREAKING: Automatically use the
    "archive_name_format" option to filter which archives
    get used for borgmatic actions that operate on multiple
    archives. Override this behavior with the
    new "match_archives" option in the storage section. This
    change is "breaking" in that it silently
    changes which archives get considered for "rlist",
    "prune", "check", etc.
  * The "prefix" options have been deprecated in
    favor of the new "archive_name_format"
    auto-matching behavior and the "match_archives" option.
  * Add "--log-file-format" flag for customizing the log
    message format.
  * Fix regression in which the "check_repositories" option
    failed to match repositories.
  * Fix regression in which the "transfer" action produced
    a traceback.
  * Add spellchecking of source code during test runs.
* Thu Mar 30 2023 Paolo Stivanin <info@paolostivanin.com>
- update to 1.7.10:
  * #396: When a database command errors, display and log the error message instead of swallowing it.
  * #501: Optionally error if a source directory does not exist via "source_directories_must_exist"
    option in borgmatic's location configuration.
  * #576: Add support for "file://" paths within "repositories" option.
  * #612: Define and use custom constants in borgmatic configuration files. See the documentation for
    more information:
    https://torsion.org/borgmatic/docs/how-to/make-per-application-backups/#constant-interpolation
  * #618: Add support for BORG_FILES_CACHE_TTL environment variable via "borg_files_cache_ttl" option
    in borgmatic's storage configuration.
  * #623: Fix confusing message when an error occurs running actions for a configuration file.
  * #635: Add optional repository labels so you can select a repository via "--repository yourlabel"
    at the command-line. See the configuration reference for more information:
    https://torsion.org/borgmatic/docs/reference/configuration/
  * #649: Add documentation on backing up a database running in a container:
    https://torsion.org/borgmatic/docs/how-to/backup-your-databases/#containers
  * #655: Fix error when databases are configured and a source directory doesn't exist.
  * Add code style plugins to enforce use of Python f-strings and prevent single-letter variables.
    To join in the pedantry, refresh your test environment with "tox --recreate".
  * Rename scripts/run-full-dev-tests to scripts/run-end-to-end-dev-tests and make it run end-to-end
    tests only. Continue using tox to run unit and integration tests.
* Tue Mar  7 2023 Dirk Müller <dmueller@suse.com>
- update to 1.7.8:
  * #620: With the "create" action and the "--list" ("--files")
    flag, only show excluded files at verbosity 2.
  * #621: Add optional authentication to the ntfy monitoring
    hook.
  * With the "create" action, only one of "--list" ("--files")
    and "--progress" flags can be used.
  * This lines up with the new behavior in Borg 2.0.0b5.
  * Internally support new Borg 2.0.0b5 "--filter" status
    characters / item flags for the "create" action.
  * Fix the "create" action with the "--dry-run" flag querying
    for databases when a PostgreSQL/MySQL "all" database is
    configured. Now, these queries are skipped due to the dry run.
  * Add "--repository" flag to the "rcreate" action to optionally
    select one configured repository to create.
  * Add "--progress" flag to the "transfer" action, new in Borg
    2.0.0b5.
  * Add "checkpoint_volume" configuration option to creates
    checkpoints every specified number of bytes during a
    long-running backup, new in Borg 2.0.0b5.
* Tue Feb 21 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.7.7:
  * #642: Add MySQL database hook "add_drop_database" configuration option to control whether dumped
    MySQL databases get dropped right before restore.
  * #643: Fix for potential data loss (data not getting backed up) when dumping large "directory"
    format PostgreSQL/MongoDB databases. Prior to the fix, these dumps would not finish writing to
    disk before Borg consumed them. Now, the dumping process completes before Borg starts. This only
    applies to "directory" format databases; other formats still stream to Borg without using
    temporary disk space.
  * Fix MongoDB "directory" format to work with mongodump/mongorestore without error. Prior to this
    fix, only the "archive" format worked.
  * #393, #438, #560: Optionally dump "all" PostgreSQL/MySQL databases to separate files instead of one
    combined dump file, allowing more convenient restores of individual databases. You can enable
    this by specifying the database dump "format" option when the database is named "all".
  * #602: Fix logs that interfere with JSON output by making warnings go to stderr instead of stdout.
  * #622: Fix traceback when include merging configuration files on ARM64.
  * #629: Skip warning about excluded special files when no special files have been excluded.
  * #630: Add configuration options for database command customization: "list_options",
    "restore_options", and "analyze_options" for PostgreSQL, "restore_options" for MySQL, and
    "restore_options" for MongoDB.
* Wed Jan 25 2023 Antonio Larrosa <alarrosa@suse.com>
- Add patch to reduce the requirement of python 3.7 to work with
  python 3.6 so borgmatic can be used in Leap 15.5 . All the tests
  work fine so it seems python 3.7 isn't really required:
  * support-python3.6.patch
* Mon Nov 28 2022 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.7.5:
  * #463: Add "before_actions" and "after_actions" command hooks that run before/after all the
  actions for each repository. These new hooks are a good place to run per-repository steps like
  mounting/unmounting a remote filesystem.
  * #463: Update documentation to cover per-repository configurations:
  https://torsion.org/borgmatic/docs/how-to/make-per-application-backups/
  * #557: Support for Borg 2 while still working with Borg 1. This includes new borgmatic actions
  like "rcreate" (replaces "init"), "rlist" (list archives in repository), "rinfo" (show repository
  info), and "transfer" (for upgrading Borg repositories). For the most part, borgmatic tries to
  smooth over differences between Borg 1 and 2 to make your upgrade process easier. However, there
  are still a few cases where Borg made breaking changes. See the Borg 2.0 changelog for more
  information: https://www.borgbackup.org/releases/borg-2.0.html
  * #557: If you install Borg 2, you'll need to manually upgrade your existing Borg 1 repositories
  before use. Note that Borg 2 stable is not yet released as of this borgmatic release, so don't
  use Borg 2 for production until it is! See the documentation for more information:
  https://torsion.org/borgmatic/docs/how-to/upgrade/#upgrading-borg
  * #557: Rename several configuration options to match Borg 2: "remote_rate_limit" is now
  "upload_rate_limit", "numeric_owner" is "numeric_ids", and "bsd_flags" is "flags". borgmatic
  still works with the old options.
  * #557: Remote repository paths without the "ssh://" syntax are deprecated but still supported for
  now. Remote repository paths containing "~" are deprecated in borgmatic and no longer work in
  Borg 2.
  * #557: Omitting the "--archive" flag on the "list" action is deprecated when using Borg 2. Use
  the new "rlist" action instead.
  * #557: The "--dry-run" flag can now be used with the "rcreate"/"init" action.
  * #565: Fix handling of "repository" and "data" consistency checks to prevent invalid Borg flags.
  * #566: Modify "mount" and "extract" actions to require the "--repository" flag when multiple
  repositories are configured.
  * #571: BREAKING: Remove old-style command-line action flags like "--create, "--list", etc. If
  you're already using actions like "create" and "list" instead, this change should not affect you.
  * #571: BREAKING: Rename "--files" flag on "prune" action to "--list", as it lists archives, not
  files.
  * #571: Add "--list" as alias for "--files" flag on "create" and "export-tar" actions.
  * Add support for disabling TLS verification in Healthchecks monitoring hook with "verify_tls"
  option.
  * #381: BREAKING: Greatly simplify configuration file reuse by deep merging when including common
  configuration. See the documentation for more information:
  https://torsion.org/borgmatic/docs/how-to/make-per-application-backups/#include-merging
  * #473: BREAKING: Instead of executing "before" command hooks before all borgmatic actions run (and
  "after" hooks after), execute these hooks right before/after the corresponding action. E.g.,
  "before_check" now runs immediately before the "check" action. This better supports running
  timing-sensitive tasks like pausing containers. Side effect: before/after command hooks now run
  once for each configured repository instead of once per configuration file. Additionally, the
  "repositories" interpolated variable has been changed to "repository", containing the path to the
  current repository for the hook. See the documentation for more information:
  https://torsion.org/borgmatic/docs/how-to/add-preparation-and-cleanup-steps-to-backups/
  * #513: Add mention of sudo's "secure_path" option to borgmatic installation documentation.
  * #515: Fix "borgmatic borg key ..." to pass parameters to Borg in the correct order.
  * #516: Fix handling of TERM signal to exit borgmatic, not just forward the signal to Borg.
  * #517: Fix borgmatic exit code (so it's zero) when initial Borg calls fail but later retries
  succeed.
  * Change Healthchecks logs truncation size from 10k bytes to 100k bytes, corresponding to that
  same change on Healthchecks.io.
* Tue Oct 18 2022 pgajdos@suse.com
- python-six is not required
  https://trello.com/c/MO53MocR/143-remove-python3-six
* Mon Aug 15 2022 Dirk Müller <dmueller@suse.com>
- update to 1.5.24:
  * #431: Add "working_directory" option to support source directories with relative paths.
  * #444: When loading a configuration file that is unreadable due to file permissions, warn instead
    of erroring. This supports running borgmatic as a non-root user with configuration in ~/.config
    even if there is an unreadable global configuration file in /etc.
  * #469: Add "repositories" context to "before_" and "after_" command action hooks. See the
    documentation for more information:
    https://torsion.org/borgmatic/docs/how-to/add-preparation-and-cleanup-steps-to-backups/
  * #486: Fix handling of "patterns_from" and "exclude_from" options to error instead of warning when
    referencing unreadable files and "create" action is run.
  * #507: Fix Borg usage error in the "compact" action when running "borgmatic --dry-run". Now, skip
    "compact" entirely during a dry run.
  * #394: Compact repository segments and free space with new "borgmatic compact" action. Borg 1.2+
    only. Also run "compact" by default when no actions are specified, as "prune" in Borg 1.2 no
    longer frees up space unless "compact" is run.
  * #394: When using the "atime", "bsd_flags", "numeric_owner", or "remote_rate_limit" options,
    tailor the flags passed to Borg depending on the Borg version.
  * #480, #482: Fix traceback when a YAML validation error occurs.
  * #288: Add database dump hook for MongoDB.
  * #470: Move mysqldump options to the beginning of the command due to MySQL bug 30994.
  * #471: When command-line configuration override produces a parse error, error cleanly instead of
    tracebacking.
  * #476: Fix unicode error when restoring particular MySQL databases.
    Drop support for Python 3.6, which has been end-of-lifed.
    Add support for Python 3.10.
- avoid bashism in post scripts (bsc#1195391)
- light modernization of spec file
* Wed Mar 16 2022 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- Update 1.5.21 which is last that supports Python 3.6
  * #28: Optionally retry failing backups via "retries" and "retry_wait" configuration options.
  * #306: Add "list_options" MySQL configuration option for passing additional arguments to MySQL
    list command.
  * #459: Add support for old version (2.x) of jsonschema library.
  * #387: Fix error when configured source directories are not present on the filesystem at the time
    of backup. Now, Borg will complain, but the backup will still continue.
  * #455: Mention changing borgmatic path in cron documentation.
    Update sample systemd service file with more granular read-only filesystem settings.
  * Move Gitea and GitHub hosting from a personal namespace to an organization for better
    collaboration with related projects.
  * #389: Fix "message too long" error when logging to rsyslog.
  * #440: Fix traceback that can occur when dumping a database.
* Fri Sep 10 2021 Dominique Leuenberger <dimstar@opensuse.org>
- ExcludeArch %%ix86: this is a bit a special trick, but as there is
  no pandoc for intel/i586 arch, we can't build there anyway. As
  the resulting package is noarch though, it does not matter much.
* Wed Jul 28 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.5.17
  * Fix error when configuration file contains "umask" option.
  * Remove test dependency on vim and /dev/urandom.
- Update to 1.5.16
  * Suppress console output in sample crontab and
    systemd service files.
  * Fix syslog logging on FreeBSD.
  * Fix hang when restoring a PostgreSQL "tar" format database dump.
  * Better error messages! Switch the library used
    for validating configuration files
  * Link borgmatic Ansible role from installation documentation:
* Wed Jun 30 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 1.5.15
  * Document use case of running backups conditionally based on
    laptop power level
  * Run arbitrary Borg commands with new "borgmatic borg" action
* Wed Jun  9 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.5.14:
  * Add link to Hetzner storage offering from the documentation.
  * Clarify canonical home of borgmatic in documentation.
  * Clarify that spaces in path names should not be backslashed
    in path names.
  * Fix error handling to error loudly when Borg gets killed due to
    running out of memory!
  * Fix build so as not to attempt to build and push documentation
    for a non-master branch.
* Wed Mar 31 2021 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.5.13:
  * #373: Document that passphrase is used for Borg keyfile encryption,
    not just repokey encryption.
  * #404: Add support for ruamel.yaml 0.17.x YAML parsing library.
  * Update systemd service example to return a permission error when
    a system call isn't permitted
    (instead of terminating borgmatic outright).
  * Drop support for Python 3.5, which has been end-of-lifed.
  * Add support for Python 3.9.
  * Only support black code formatter on Python 3.8+.
- Drop 0001-Update-versions-of-test-dependencies.patch
- Rebase skip-tests.patch
* Tue Feb  9 2021 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.5.12
  * Fix for previous release with incorrect version suffix in
    setup.py. No other changes.
- Update to 1.5.11
  * #341: Add "temporary_directory" option for changing Borg's
    temporary directory.
  * #352: Lock down systemd security settings in sample systemd
    service file.
  * #355: Fix traceback when a database hook value is null in
    a configuration file.
  * #361: Merge override values when specifying the "--override"
    flag multiple times. The previous behavior was to take the
    value of the last "--override" flag only.
  * #367: Fix traceback when upgrading old INI-style configuration
    with upgrade-borgmatic-config.
  * #368: Fix signal forwarding from borgmatic to Borg resulting
    in recursion traceback.
  * #369: Document support for Borg placeholders in repository
    names.
- Replace patch:
  * remove-invalid-test.patch
  with patch from upstream that fixes tests:
  * 0001-Update-versions-of-test-dependencies.patch
* Mon Aug 31 2020 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.5.10
  * #347: Add hooks that run for the "extract" action:
    "before_extract" and "after_extract".
  * #350: Fix traceback when a configuration directory is
    non-readable due to directory permissions.
  * Add documentation navigation links on left side of all
    documentation pages.
  * Clarify documentation on configuration overrides, specifically
    the portion about list syntax:
    http://torsion.org/borgmatic/docs/how-to/make-per-application-backups/#configuration-overrides
  * Clarify documentation overview of monitoring options:
    http://torsion.org/borgmatic/docs/how-to/monitor-your-backups/
* Tue Jul 28 2020 Martin Rey <mrey@suse.com>
- Update to 1.5.9
  * #300: Add “borgmatic export-tar” action to export an archive to
    a tar-formatted file or stream.
  * #339: Fix for intermittent timing-related test failure of
    logging function.
  * Clarify database documentation about excluding named pipes and
    character/block devices to prevent hangs.
* Tue Jul  7 2020 Martin Rey <mrey@suse.com>
- Update to 1.5.8
  * #336: Fix for traceback when running Cronitor, Cronhub, and
    PagerDuty monitor hooks.
- Update to 1.5.7
  * #327: Fix broken pass-through of BORG_* environment variables
    to Borg.
  * #328: Fix duplicate logging to Healthchecks and send "after_*"
    hooks output to Healthchecks.
  * #331: Add SSL support to PostgreSQL database configuration.
  * #333: Fix for potential data loss (data not getting backed up)
    when borgmatic omitted configured source directories in certain
    situations. Specifically, this occurred when two source
    directories on different filesystems were related by parentage
    (e.g. "/foo" and "/foo/bar/baz") and the one_file_system option
    was enabled.
  * Update documentation code fragments theme to better match the
    rest of the page.
  * Improve configuration reference documentation readability via
    more aggressive word-wrapping in configuration schema
    descriptions.
* Mon Jun 15 2020 Martin Rey <mrey@suse.com>
- Update to 1.5.6
  * #292: Allow before_backup and similiar hooks to exit with a
    soft failure without altering the monitoring status on
    Healthchecks or other providers. Support this by waiting to
    ping monitoring services with a "start" status until after
    before_* hooks finish. Failures in before_* hooks still trigger
    a monitoring "fail" status.
  * #316: Fix hang when a stale database dump named pipe from an
    aborted borgmatic run remains on disk.
  * #323: Fix for certain configuration options like ssh_command
    impacting Borg invocations for separate configuration files.
  * #324: Add "borgmatic extract --strip-components" flag to remove
    leading path components when extracting an archive.
  * Tweak comment indentation in generated configuration file for
    clarity.
  * Link to Borgmacator GNOME AppIndicator from monitoring
    documentation.
* Wed May 27 2020 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.5.5
  * #314: Fix regression in support for PostgreSQL's "directory" dump format. Unlike other dump
    formats, the "directory" dump format does not stream directly to/from Borg.
  * #315: Fix enabled database hooks to implicitly set one_file_system configuration option to true.
  * This prevents Borg from reading devices like /dev/zero and hanging.
  * #316: Fix hang when streaming a database dump to Borg with implicit duplicate source directories
    by deduplicating them first.
  * #319: Fix error message when there are no MySQL databases to dump for "all" databases.
  * Improve documentation around the installation process. Specifically, making borgmatic commands
    runnable via the system PATH and offering a global install option.
- Update to 1.5.4
  * #310: Fix legitimate database dump command errors (exit code 1) not being treated as errors by
    borgmatic.
  * For database dumps, replace the named pipe on every borgmatic run. This prevent hangs on stale
    pipes left over from previous runs.
  * Fix error handling to handle more edge cases when executing commands.
- Update to 1.5.3
  * #258: Stream database dumps and restores directly to/from Borg without using any additional
    filesystem space. This feature is automatic, and works even on restores from archives made with
    previous versions of borgmatic.
  * #293: Documentation on macOS launchd permissions issues with work-around for Full Disk Access.
  * Remove "borgmatic restore --progress" flag, as it now conflicts with streaming database restores.
- Update to 1.5.2
  * #301: Fix MySQL restore error on "all" database dump by excluding system tables.
  * Fix PostgreSQL restore error on "all" database dump by using "psql" for the restore instead of
    "pg_restore".
- Add skip-tests.patch
* Mon May 25 2020 Antonio Larrosa <alarrosa@suse.com>
- Comment the LogRateLimitIntervalSec option in the systemd service
  when building for SLE/Leap since systemd < 240 doesn't support it.
* Mon May 25 2020 Antonio Larrosa <alarrosa@suse.com>
- Remove unneeded build dependency python-black and python-devel
- Reduce the required python-colorama version since a newer
  version is not really needed.
* Mon May  4 2020 Antonio Larrosa <alarrosa@suse.com>
- Add patch to remove invalid test:
  * remove-invalid-test.patch
* Sat Mar 14 2020 Antonio Larrosa <alarrosa@suse.com>
- Use `python3 -m venv` instead of invoking pyvenv which doesn't seem
  to exist anymore with python 3.8.
* Sun Feb 23 2020 simmphonie@opensuse.org
- Fix execution path in borgmatic.service
* Tue Feb  4 2020 Martin Rey <mrey@suse.com>
- Update to 1.5.1
  * #289: Tired of looking up the latest successful archive name in
  order to pass it to borgmatic actions? Me too. Now you can
  specify "--archive latest" to all actions that accept an archive
  flag.
  * 290: Fix the "--stats" and "--files" flags so that they yield
  output at verbosity 0.
  * Reduce the default verbosity of borgmatic logs sent to
  Healthchecks monitoring hook. Now, it's warnings and errors
  only. You can increase the verbosity via the
  "--monitoring-verbosity" flag.
  * Add security policy documentation in SECURITY.md.
* Tue Jan 28 2020 Martin Rey <mrey@suse.com>
- Update to 1.5.0
  * #245: Monitor backups with PagerDuty hook integration. See the
  documentation for more information:
  https://torsion.org/borgmatic/docs/how-to/monitor-your-backups/#pagerduty-hook
  * #255: Add per-action hooks: "before_prune", "after_prune",
  "before_check", and "after_check".
  * #274: Add ~/.config/borgmatic.d as another configuration
  directory default.
  * #277: Customize Healthchecks log level via borgmatic
  "--monitoring-verbosity" flag.
  * #280: Change "exclude_if_present" option to support multiple
  filenames that indicate a directory should be excluded from
  backups, rather than just a single filename.
  * #284: Backup to a removable drive or intermittent server via
  "soft failure" feature. See the documentation for more
  information:
  https://torsion.org/borgmatic/docs/how-to/backup-to-a-removable-drive-or-an-intermittent-server/
  * #287: View consistency check progress via "--progress" flag for
  "check" action. For "create" and "prune" actions, no longer list
  files or show detailed stats at any verbosities by default. You
  can opt back in with "--files" or "--stats" flags. For "list"
  and "info" actions, show repository names even at verbosity 0.
* Wed Jan 22 2020 Martin Rey <mrey@suse.com>
- Update to 1.4.2
  * Extract files to a particular directory via "borgmatic extract --destination" flag.
  * Rename "borgmatic extract --restore-path" flag to "--path" to reduce confusion with the separate
  "borgmatic restore" action. Any uses of "--restore-path" will continue working.
- Update to 1.4.1
  * #229: Restore backed up PostgreSQL databases via "borgmatic restore" action. See the
  documentation for more information:
  https://torsion.org/borgmatic/docs/how-to/backup-your-databases/
  * Documentation on how to develop borgmatic's documentation:
  https://torsion.org/borgmatic/docs/how-to/develop-on-borgmatic/#documentation-development
- Update to 1.4.0
  * #225: Database dump hooks for PostgreSQL, so you can easily dump your databases before backups
  run.
  * #230: Rename "borgmatic list --pattern-from" flag to "--patterns-from" to match Borg.
- Update to 1.3.26
  * #224: Fix "borgmatic list --successful" with a slightly better heuristic for listing successful
  (non-checkpoint) archives.
- Update to 1.3.25
  * #223: Dead man's switch to detect when backups start failing silently, implemented via
  healthchecks.io hook integration. See the documentation for more information:
  https://torsion.org/borgmatic/docs/how-to/monitor-your-backups/#healthchecks-hook
  * Documentation on monitoring and alerting options for borgmatic backups:
  https://torsion.org/borgmatic/docs/how-to/monitor-your-backups/
  * Automatically rewrite links when developing on documentation locally.
- Update to 1.3.24
  * #86: Add "borgmatic list --successful" flag to only list successful (non-checkpoint) archives.
  * Add a suggestion form to all documentation pages, so users can submit ideas for improving the
  documentation.
  * Update documentation link to community Arch Linux borgmatic package.
- Update to 1.3.23
  * #174: More detailed error alerting via runtime context available in "on_error" hook.
- Update to 1.3.22
  * #144: When backups to one of several repositories fails, keep backing up to the other
  repositories and report errors afterwards.
- Update to 1.3.21
  * #192: User-defined hooks for global setup or cleanup that run before/after all actions. See the
  documentation for more information:
  https://torsion.org/borgmatic/docs/how-to/add-preparation-and-cleanup-steps-to-backups/
- Update to 1.3.20
  * #205: More robust sample systemd service: boot delay, network dependency, lowered CPU/IO
  priority, etc.
  * #221: Fix "borgmatic create --progress" output so that it updates on the console in real-time.
- Update to 1.3.19
  * #219: Fix visibility of "borgmatic prune --stats" output.
- Update to 1.3.18
  * #220: Fix regression of argument parsing for default actions.
- Update to 1.3.17
  * #217: Fix error with "borgmatic check --only" command-line flag with "extract" consistency check.
- Update to 1.3.16
  * #210: Support for Borg check --verify-data flag via borgmatic "data" consistency check.
  * #210: Override configured consistency checks via "borgmatic check --only" command-line flag.
  * When generating sample configuration with generate-borgmatic-config, add a space after each "#"
  comment indicator.
- Update to 1.3.15
  * #208: Fix for traceback when the "checks" option has an empty value.
  * #209: Bypass Borg error about a moved repository via "relocated_repo_access_is_ok" option in
  borgmatic storage configuration section.
  * #213: Reorder arguments passed to Borg to fix duplicate directories when using Borg patterns.
  * #214: Fix for hook erroring with exit code 1 not being interpreted as an error.
* Thu Dec 19 2019 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libsystemd) instead of systemd-devel:
  Allow OBS to shortcut through the -mini flavors.
* Tue Sep  3 2019 Antonio Larrosa <alarrosa@suse.com>
- Fix regexes in spec file now that upstream changed the default borgmatic
  location in the cron and systemd sample files, so we replace them correctly
  with the /usr/bin locations we need for borgmatic to be found.
- Add missing python3-colorama runtime dependency
* Wed Aug 21 2019 simmphonie@opensuse.org
- Update to 1.3.14
  * #204: Do not treat Borg warnings (exit code 1) as failures.
  * When validating configuration files, require strings instead of allowing any scalar type.
- Update to 1.3.13
  * #199: Add note to documentation about using spaces instead of tabs for indentation, as YAML does
  not allow tabs.
  * #203: Fix compatibility with ruamel.yaml 0.16.x.
  * If a "prefix" option in borgmatic's configuration has an empty value (blank or ""), then disable
  default prefix.
- Update to 1.3.12
  * Only log to syslog when run from a non-interactive console (e.g. a cron job).
  * Remove unicode byte order mark from syslog output so it doesn't show up as a literal in rsyslog
  output. See discussion on #197.
- Update to 1.3.11
  * #193: Pass through several "borg list" and "borg info" flags like --short, --format, --sort-by,
  - -first, --last, etc. via borgmatic command-line flags.
  * Add borgmatic info --repository and --archive command-line flags to display info for individual
  repositories or archives.
  * Support for Borg --noatime, --noctime, and --nobirthtime flags via corresponding options in
  borgmatic configuration location section.
- Update to 1.3.10
  * #198: Fix for Borg create error output not showing up at borgmatic verbosity level zero.
- Update to 1.3.9
  * #195: Switch to command-line actions as more traditional sub-commands, e.g. "borgmatic create",
  "borgmatic prune", etc. However, the classic dashed options like "--create" still work!
- Update to 1.3.8
  * #191: Disable console color via "color" option in borgmatic configuration output section.
- Update to 1.3.7
  * #196: Fix for unclear error message for invalid YAML merge include.
  * #197: Don't color syslog output.
  * Change default syslog verbosity to show errors only.
- Update to 1.3.6
  * #53: Log to syslog in addition to existing console logging. Add --syslog-verbosity flag to
  customize the log level. See the documentation for more information:
  https://torsion.org/borgmatic/docs/how-to/inspect-your-backups/
  * #178: Look for .yml configuration file extension in addition to .yaml.
  * #189: Set umask used when executing hooks via "umask" option in borgmatic hooks section.
  * Remove Python cache files before each Tox run.
  * Add #borgmatic Freenode IRC channel to documentation.
  * Add Borg/borgmatic hosting providers section to documentation.
  * Add files for building documentation into a Docker image for web serving.
  * Upgrade project build server from Drone 0.8 to 1.1.
  * Build borgmatic documentation during continuous integration.
  * We're nearly at 500 ★s on GitHub. We can do this!
- Update to 1.3.5
  * #153: Support for various Borg directory environment variables (BORG_CONFIG_DIR, BORG_CACHE_DIR,
  etc.) via options in borgmatic's storage configuration.
  * #177: Fix for regression with missing verbose log entries.
- Update to 1.3.4
  * Part of #125: Color borgmatic (but not Borg) output when using an interactive terminal.
  * #166: Run tests for all installed versions of Python.
  * #168: Update README with continuous integration badge.
  * #169: Automatically sort Python imports in code.
  * Document installing borgmatic with pip install --user instead of a system Python install.
  * Get more reproducible builds by pinning the versions of pip and tox used to run tests.
  * Factor out build/test configuration from tox.ini file.
- Update to 1.3.3
  * Add validate-borgmatic-config command, useful for validating borgmatic config generated by
  configuration management or even edited by hand.
- Update to 1.3.2
  * #160: Fix for hooks executing when using --dry-run. Now hooks are skipped during a dry run.
* Sun May  5 2019 Torsten Gruner <t.gruner@katodev.de>
- Update to 1.3.1
  * #155: Fix for invalid JSON output when using multiple borgmatic configuration files.
  * #157: Fix for seemingly random filename ordering when running through a directory of
    configuration files.
  * Fix for empty JSON output when using --create --json.
  * Now capturing Borg output only when --json flag is used. Previously, borgmatic delayed Borg
    output even without the --json flag.
- Update to 1.3.0
  * #148: Configuration file includes and merging via "!include" tag to support reuse of common
    options across configuration files.
- Update to 1.2.18
  * #147: Support for Borg create/extract --numeric-owner flag via "numeric_owner" option in
    borgmatic's location section.
- Update to 1.2.17
  * #140: List the files within an archive via --list --archive option.
- Update to 1.2.16
  * #119: Include a sample borgmatic configuration file in the documentation.
  * #123: Support for Borg archive restoration via borgmatic --extract command-line flag.
  * Refactor documentation into multiple separate pages for clarity and findability.
  * Organize options within command-line help into logical groups.
  * Exclude tests from distribution packages.
- Update to 1.2.15
  * #127: Remove date echo from schema example, as it's not a substitute for real logging.
  * #132: Leave exclude_patterns glob expansion to Borg, since doing it in borgmatic leads to
    confusing behavior.
  * #136: Handle and format validation errors raised during argument parsing.
  * #138: Allow use of --stats flag when --create or --prune flags are implied.
* Mon Jan 21 2019 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.2.14
  * When generating sample configuration with generate-borgmatic-config,
    document the defaults for each option.
  * When running multiple configuration files, attempt all configuration
    files even if one of them errors. Log a summary of results at the end.
  * Add borgmatic --version command-line flag to get the current installed
    version number.
- Update to 1.2.13
  * Support for --stats command-line flag independent of --verbosity.
  * With borgmatic --init command-line flag, proceed without erroring if a
    repository already exists.
- Update to 1.2.12
  * Support for Borg repository initialization via borgmatic --init
    command-line flag.
  * Update Borg create --filter values so a dry run lists files to back up.
  * Update README with link to a new/forked Docker image.
  * Prevent deprecated --excludes command-line option from being used.
  * Refactor README a bit to flow better for first-time users.
  * Update README with a few additional borgmatic packages (Debian and Ubuntu).
- Update to 1.2.11
  * Support for Borg create --progress via borgmatic command-line flag.
- Update to 1.2.10
  * Support for Borg --chunker-params create option via "chunker_params"
    in borgmatic's storage section.
- Update to 1.2.9
  * Fix for syntax error that occurred in Python 3.5 and below.
  * Make automated tests support running in Python 3.5.
- Update to 1.2.8
  * Enable consistency checks for only certain repositories via
    "check_repositories" option in borgmatic's consistency
    configuration. Handy for large repositories that take forever to check.
  * Include link to issue tracker within various command output.
  * Run continuous integration tests on a matrix of Python and Borg
    versions.
- Update to 1.2.7
  * Support for Borg --keep-secondly prune option.
  * Use Black code formatter and Flake8 code checker as part of running
    automated tests.
  * Add an end-to-end automated test that actually integrates with Borg.
  * Set up continuous integration for borgmatic automated tests
- Update to 1.2.6
  * Fix generated configuration to also include a "keep_daily" value so
    pruning works out of the box.
- Update to 1.2.5
  * Fix various warnings.
- Update to 1.2.4
  * Bump version.
- Update to 1.2.3
  * Set to release version.
* Fri Sep 14 2018 Antonio Larrosa <alarrosa@suse.com>
- Update to 1.2.2
  * #85: Fix compatibility issue between pykwalify and ruamel.yaml 0.15.52, which manifested in
  borgmatic as a pykwalify RuleError.
- Update to 1.2.1
  * Skip before/after backup hooks when only doing --prune, --check, --list, and/or --info.
  * #71: Support for XDG_CONFIG_HOME environment variable for specifying alternate user ~/.config/
  path.
  * #74, #83: Support for Borg --json option via borgmatic command-line to --list archives or show
  archive --info in JSON format, ideal for programmatic consumption.
  * #38, #76: Upgrade ruamel.yaml compatibility version range and fix support for Python 3.7.
  * #77: Skip non-"*.yaml" config filenames in /etc/borgmatic.d/ so as not to parse backup files,
  editor swap files, etc.
  * #81: Document user-defined hooks run before/after backup, or on error.
  * Add code style guidelines to the documention.
* Sat Jul  7 2018 alarrosa@suse.com
- Use %%{version} in the Source line instead of explicitly writing it.
- Use %%license for LICENSE and change the license in the spec file to
  GPL-3.0-only
* Fri Jul  6 2018 t.gruner@katodev.de
- update to 1.2.0
  * #61: Support for Borg --list option via borgmatic command-line to list all archives.
  * #61: Support for Borg --info option via borgmatic command-line to display summary information.
  * #62: Update README to mention other ways of installing borgmatic.
  * Support for Borg --prefix option for consistency checks via "prefix" option in borgmatic's
  consistency configuration.
  * Add introductory screencast link to documentation.
  * #59: Ignore "check_last" and consistency "prefix" when "archives" not in consistency checks.
  * #60: Add "Persistent" flag to systemd timer example.
  * #63: Support for Borg --nobsdflags option to skip recording bsdflags (e.g. NODUMP, IMMUTABLE) in
  archive.
  * #69: Support for Borg prune --umask option using value of existing "umask" option in borgmatic's
  storage configuration.
  * Update tox.ini to only assume Python 3.x instead of Python 3.4 specifically.
  * Add ~/.config/borgmatic/config.yaml to default configuration path probing.
  * Document how to develop on and contribute to borgmatic.
* Tue Mar 27 2018 t.gruner@katodev.de
- Use README.md form source
- Add borgmatic.d folder in /etc for config files
- Update to 1.1.15
  * Support for Borg BORG_PASSCOMMAND environment variable to read a password from an external file.
  * Fix for Borg create error when using borgmatic's --dry-run and --verbosity options together.
  Work-around for behavior introduced in Borg 1.1.3: https://github.com/borgbackup/borg/issues/3298
  * #55: Fix for missing tags/releases on Gitea and GitHub project hosting.
  * #56: Support for Borg --lock-wait option for the maximum wait for a repository/cache lock.
  * #58: Support for using tilde in exclude_patterns to reference home directory.
* Tue Jan 30 2018 alarrosa@suse.com
- Removed _service file. Borgmatic uses to have frequent releases these days.
- Update to 1.1.14
  * Fix for typo in --patterns-from option.
  * Support for Borg --dry-run option via borgmatic command-line.
- Update to 1.1.13
  * Fix for incorrect consistency check flags passed to Borg when all three checks ("repository",
    "archives", and "extract") are specified in borgmatic configuration.
  * Add "local_path" to configuration for specifying an alternative Borg executable path.
  * Support for Borg experimental --patterns-from and --patterns options for specifying mixed
    includes/excludes.
  * Moved issue tracker from Taiga to integrated Gitea tracker at
    https://projects.torsion.org/witten/borgmatic/issues
- Update to 1.1.12
  * Declare dependency on pykwalify 1.6 or above, as older versions yield "Unknown key: version"
    rule errors.
  * Support for Borg --keep-minutely prune option.
- Update to 1.1.11
  * Add "ssh_command" to configuration for specifying a custom SSH command or options.
  * Fix for incorrect /etc/borgmatic.d/ configuration path probing on macOS. This problem manifested
    as an error on startup: "[Errno 2] No such file or directory: '/etc/borgmatic.d'".
- Update to 1.1.10
  * Pass several Unix signals through to child processes like Borg. This means that Borg now properly
    shuts down if borgmatic is terminated (e.g. due to a system suspend).
  * Support for using tilde in repository paths to reference home directory.
  * Support for Borg --files-cache option for setting the files cache operation mode.
  * Support for Borg --remote-ratelimit option for limiting upload rate.
  * Log invoked Borg commands when at highest verbosity level.
* Sun Oct 29 2017 alarrosa@suse.com
- Upstream moved from mercurial to git, so updated _service accordingly,
  updated source code to 6e9e7c4 and set all services mode to disabled.
- Fixed a too restrictive python3-ruamel.yaml version requirement
  in the source code
- Add a rcborgmatic symlink as required by the suse-missing-rclink rpmlint check
* Wed Sep 20 2017 alarrosa@suse.com
- Update to 1.1.9dev0-201
  * #29: Support for using tilde in source directory path to reference home directory.
- python3-ruamel.yaml and python3-pykwalify are now required
- Update to 1.1.8
  * #39: Fix to make /etc/borgmatic/config.yaml optional rather than required when using the default
    config paths.
- Update to 1.1.7
  * #28: Add "archive_name_format" to configuration for customizing archive names.
  * Fix for traceback when "exclude_from" value is empty in configuration file.
  * When pruning, make highest verbosity level list archives kept and pruned.
  * Clarification of Python 3 pip usage in documentation.
- Update to 1.1.6
  * #12, #35: Support for Borg --exclude-from, --exclude-caches, and --exclude-if-present options.
- Update to 1.1.5
  * #34: New "extract" consistency check that performs a dry-run extraction of the most recent
    archive.
- Update to 1.1.4
  * #17: Added command-line flags for performing a borgmatic run with only pruning, creating, or
    checking enabled. This supports use cases like running consistency checks from a different cron
    job with a different frequency, or running pruning with a different verbosity level.
- Update to 1.1.3
  * #14: Support for running multiple config files in /etc/borgmatic.d/ from a single borgmatic run.
  * Fix for generate-borgmatic-config writing config with invalid one_file_system value.
- Update to 1.1.2
  * #32: Fix for passing check_last as integer to subprocess when calling Borg.
- Update to 1.1.1
  * Part of #32: Fix for upgrade-borgmatic-config converting check_last option as a string instead of
    an integer.
  * Fix for upgrade-borgmatic-config erroring when consistency checks option is not present.
- Update to 1.1.0
  * Switched config file format to YAML. Run upgrade-borgmatic-config to upgrade.
  * Added generate-borgmatic-config command for initial config creation.
  * Dropped Python 2 support. Now Python 3 only.
  * #18: Fix for README mention of sample files not included in package.
  * #22: Sample files for triggering borgmatic from a systemd timer.
  * Support for backing up to multiple repositories.
  * To free up space, now pruning backups prior to creating a new backup.
  * Enabled test coverage output during tox runs.
  * Added logo.
* Wed Mar  8 2017 sfalken@opensuse.org
- Edited %%files to clear unpackaged files builderror in
  openSUSE:Factory
* Sun Oct 30 2016 jengelh@inai.de
- Trim and wrap description
* Thu Oct 13 2016 alarrosa@suse.com
- version 1.0.3-dev: initial build
